@@ -32,12 +32,13 @@
 //
 ///////////////////////////////////////////////////////////////////////////
 
-#include <PyImathBasicTypes.h>
+#include "PyImathBasicTypes.h"
 #include <Python.h>
 #include <boost/python.hpp>
-#include <PyImath.h>
-#include <PyImathFixedArray.h>
-#include <PyImathFixedVArray.h>
+#include "PyImath.h"
+#include "PyImathExport.h"
+#include "PyImathFixedArray.h"
+#include "PyImathFixedVArray.h"
 
 using namespace boost::python;
 
