@@ -40,7 +40,7 @@
 #include <boost/python/make_constructor.hpp>
 #include <Iex.h>
 #include <ImathBoxAlgo.h>
-#include <PyImathTask.h>
+#include "PyImathTask.h"
 #include <vector>
 #include "PyImathBoxArrayImpl.h"
 
@@ -191,13 +191,21 @@ static std::string Box2_repr(const Box<T> &box)
 
     PyObject *minObj = converter (box.min);
     PyObject *minReprObj = PyObject_Repr (minObj);
+#if PY_MAJOR_VERSION > 2
+    std::string minReprStr = PyUnicode_AsUTF8 (minReprObj);
+#else
     std::string minReprStr = PyString_AsString (minReprObj);
+#endif
     Py_DECREF (minReprObj);
     Py_DECREF (minObj);
 
     PyObject *maxObj = converter (box.max);
     PyObject *maxReprObj = PyObject_Repr (maxObj);
+#if PY_MAJOR_VERSION > 2
+    std::string maxReprStr = PyUnicode_AsUTF8 (maxReprObj);
+#else
     std::string maxReprStr = PyString_AsString (maxReprObj);
+#endif
     Py_DECREF (maxReprObj);
     Py_DECREF (maxObj);
 
@@ -214,13 +222,21 @@ static std::string Box3_repr(const Box<T> &box)
 
     PyObject *minObj = converter (box.min);
     PyObject *minReprObj = PyObject_Repr (minObj);
+#if PY_MAJOR_VERSION > 2
+    std::string minReprStr = PyUnicode_AsUTF8 (minReprObj);
+#else
     std::string minReprStr = PyString_AsString (minReprObj);
+#endif
     Py_DECREF (minReprObj);
     Py_DECREF (minObj);
 
     PyObject *maxObj = converter (box.max);
     PyObject *maxReprObj = PyObject_Repr (maxObj);
+#if PY_MAJOR_VERSION > 2
+    std::string maxReprStr = PyUnicode_AsUTF8 (maxReprObj);
+#else
     std::string maxReprStr = PyString_AsString (maxReprObj);
+#endif
     Py_DECREF (maxReprObj);
     Py_DECREF (maxObj);
 
@@ -243,14 +259,14 @@ static void boxSetMax(IMATH_NAMESPACE::Box<T> &box, const T &m)
 
 template <class T>
 static T
-boxMin(Imath::Box<T> &box)
+boxMin(IMATH_NAMESPACE::Box<T> &box)
 {
     return box.min;
 }
 
 template <class T>
 static T
-boxMax(Imath::Box<T> &box)
+boxMax(IMATH_NAMESPACE::Box<T> &box)
 {
     return box.max;
 }
