@@ -38,16 +38,16 @@
 // order to work around MSVC limitations.
 //
 
-#include <PyImathColor.h>
-#include <PyImathVec.h>
+#include "PyImathColor.h"
+#include "PyImathVec.h"
 #include "PyImathDecorators.h"
 #include "PyImathExport.h"
 #include <Python.h>
 #include <boost/python.hpp>
 #include <boost/python/make_constructor.hpp>
 #include <boost/format.hpp>
-#include <PyImath.h>
-#include <PyImathMathExc.h>
+#include "PyImath.h"
+#include "PyImathMathExc.h"
 #include <ImathVec.h>
 #include <ImathColor.h>
 #include <ImathColorAlgo.h>
@@ -545,7 +545,7 @@ static bool
 greaterThan(Color3<T> &v, const Color3<T> &w)
 {
     bool isGreaterThan = (v.x >= w.x && v.y >= w.y && v.z >= w.z)
-                       & v != w;
+                       && v != w;
                    
    return isGreaterThan;
 }
