@@ -32,15 +32,15 @@
 //
 ///////////////////////////////////////////////////////////////////////////
 
-#include <PyImathColor.h>
+#include "PyImathColor.h"
 #include "PyImathDecorators.h"
 #include "PyImathExport.h"
 #include <Python.h>
 #include <boost/python.hpp>
 #include <boost/python/make_constructor.hpp>
 #include <boost/format.hpp>
-#include <PyImath.h>
-#include <PyImathMathExc.h>
+#include "PyImath.h"
+#include "PyImathMathExc.h"
 #include <ImathColor.h>
 #include <ImathColorAlgo.h>
 #include <Iex.h>
@@ -543,7 +543,7 @@ static bool
 greaterThan(Color4<T> &v, const Color4<T> &w)
 {
     bool isGreaterThan = (v.r >= w.r && v.g >= w.g && v.b >= w.b && v.a >= w.a)
-                       & v != w;
+                       && v != w;
                    
    return isGreaterThan;
 }
