@@ -193,7 +193,11 @@ class FixedArray2D
     void extract_slice_indices(PyObject *index, size_t length, size_t &start, size_t &end, Py_ssize_t &step, size_t &slicelength) const
     {
         if (PySlice_Check(index)) {
+#if PY_MAJOR_VERSION > 2
+            PyObject *slice = index;
+#else
             PySliceObject *slice = reinterpret_cast<PySliceObject *>(index);
+#endif
             Py_ssize_t s, e, sl;
             if (PySlice_GetIndicesEx(slice,length,&s,&e,&step,&sl) == -1) {
                 boost::python::throw_error_already_set();
@@ -204,8 +208,13 @@ class FixedArray2D
             start = s;
             end = e;
             slicelength = sl;
+#if PY_MAJOR_VERSION > 2
+        } else if (PyLong_Check(index)) {
+            size_t i = canonical_index(PyLong_AsSsize_t(index), length);
+#else
         } else if (PyInt_Check(index)) {
             size_t i = canonical_index(PyInt_AsSsize_t(index), length);
+#endif
             start = i; end = i+1; step = 1; slicelength = 1;
         } else {
             PyErr_SetString(PyExc_TypeError, "Object is not a slice");
@@ -691,6 +700,8 @@ static void add_arithmetic_math_functions(boost::python::class_<FixedArray2D<T>
         .def("__rmul__",&apply_array2d_scalar_binary_rop<op_mul,T,T,T>)
         .def("__div__",&apply_array2d_array2d_binary_op<op_div,T,T,T>)
         .def("__div__",&apply_array2d_scalar_binary_op<op_div,T,T,T>)
+        .def("__truediv__",&apply_array2d_array2d_binary_op<op_div,T,T,T>)
+        .def("__truediv__",&apply_array2d_scalar_binary_op<op_div,T,T,T>)
         .def("__neg__",&apply_array2d_unary_op<op_neg,T,T>)
         .def("__iadd__",&apply_array2d_array2d_ibinary_op<op_iadd,T,T>,return_internal_reference<>())
         .def("__iadd__",&apply_array2d_scalar_ibinary_op<op_iadd,T,T>,return_internal_reference<>())
@@ -700,6 +711,8 @@ static void add_arithmetic_math_functions(boost::python::class_<FixedArray2D<T>
         .def("__imul__",&apply_array2d_scalar_ibinary_op<op_imul,T,T>,return_internal_reference<>())
         .def("__idiv__",&apply_array2d_array2d_ibinary_op<op_idiv,T,T>,return_internal_reference<>())
         .def("__idiv__",&apply_array2d_scalar_ibinary_op<op_idiv,T,T>,return_internal_reference<>())
+        .def("__itruediv__",&apply_array2d_array2d_ibinary_op<op_idiv,T,T>,return_internal_reference<>())
+        .def("__itruediv__",&apply_array2d_scalar_ibinary_op<op_idiv,T,T>,return_internal_reference<>())
         ;
 }
 
