@@ -33,17 +33,17 @@
 ///////////////////////////////////////////////////////////////////////////
 
 
-#include <PyImathShear.h>
+#include "PyImathShear.h"
 
-#include <PyImathPlane.h>
+#include "PyImathPlane.h"
 #include "PyImathDecorators.h"
 #include "PyImathExport.h"
 #include <Python.h>
 #include <boost/python.hpp>
 #include <boost/python/make_constructor.hpp>
 #include <boost/format.hpp>
-#include <PyImath.h>
-#include <PyImathMathExc.h>
+#include "PyImath.h"
+#include "PyImathMathExc.h"
 #include <Iex.h>
 
 
