@@ -41,21 +41,21 @@
 // order to work around MSVC limitations.
 //
 
-#include <PyImathVec.h>
+#include "PyImathVec.h"
 #include "PyImathDecorators.h"
 #include <Python.h>
 #include <boost/python.hpp>
 #include <boost/python/make_constructor.hpp>
 #include <boost/format.hpp>
-#include <PyImath.h>
-#include <PyImathBox.h>
+#include "PyImath.h"
+#include "PyImathBox.h"
 #include <ImathVec.h>
 #include <ImathVecAlgo.h>
 #include <Iex.h>
-#include <PyImathMathExc.h>
+#include "PyImathMathExc.h"
 #include <boost/cast.hpp>
-#include <PyImathOperators.h>
-#include <PyImathVecOperators.h>
+#include "PyImathOperators.h"
+#include "PyImathVecOperators.h"
 
 namespace PyImath {
 using namespace boost::python;
@@ -708,7 +708,7 @@ greaterThan(const Vec2<T> &v, const object &obj)
         THROW(IEX_NAMESPACE::LogicExc, "invalid parameters passed to operator >");
     
     bool isGreaterThan = (v.x >= w.x && v.y >= w.y)
-                       & v != w;
+                       && v != w;
 
     return isGreaterThan;
 }
