@@ -43,25 +43,25 @@
 #include <ImathFun.h>
 #include <ImathMatrixAlgo.h>
 #include <PyIexExport.h>
-#include <PyImathFixedArray.h>
-#include <PyImath.h>
-#include <PyImathExport.h>
-#include <PyImathBasicTypes.h>
-#include <PyImathVec.h>
-#include <PyImathMatrix.h>
-#include <PyImathBox.h>
-#include <PyImathFun.h>
-#include <PyImathQuat.h>
-#include <PyImathEuler.h>
-#include <PyImathColor.h>
-#include <PyImathFrustum.h>
-#include <PyImathPlane.h>
-#include <PyImathLine.h>
-#include <PyImathRandom.h>
-#include <PyImathShear.h>
-#include <PyImathMathExc.h>
-#include <PyImathAutovectorize.h>
-#include <PyImathStringArrayRegister.h>
+#include "PyImathFixedArray.h"
+#include "PyImath.h"
+#include "PyImathExport.h"
+#include "PyImathBasicTypes.h"
+#include "PyImathVec.h"
+#include "PyImathMatrix.h"
+#include "PyImathBox.h"
+#include "PyImathFun.h"
+#include "PyImathQuat.h"
+#include "PyImathEuler.h"
+#include "PyImathColor.h"
+#include "PyImathFrustum.h"
+#include "PyImathPlane.h"
+#include "PyImathLine.h"
+#include "PyImathRandom.h"
+#include "PyImathShear.h"
+#include "PyImathMathExc.h"
+#include "PyImathAutovectorize.h"
+#include "PyImathStringArrayRegister.h"
 #include <PyIex.h>
 
 using namespace boost::python;
